
'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/upgrade/v1beta1/upgrade.proto\x12\x16cosmos.upgrade.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xcb\x01\n\x04Plan\x12\x0c\n\x04name\x18\x01 \x01(\t\x124\n\x04time\x18\x02 \x01(\x0b2\x1a.google.protobuf.TimestampB\n\x18\x01\x90\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04info\x18\x04 \x01(\t\x12W\n\x15upgraded_client_state\x18\x05 \x01(\x0b2\x14.google.protobuf.AnyB"\x18\x01\xf2\xde\x1f\x1cyaml:"upgraded_client_state":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"y\n\x17SoftwareUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x120\n\x04plan\x18\x03 \x01(\x0b2\x1c.cosmos.upgrade.v1beta1.PlanB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"M\n\x1dCancelSoftwareUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"8\n\rModuleVersion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x04:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x01B2Z,github.com/cosmos/cosmos-sdk/x/upgrade/types\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.upgrade.v1beta1.upgrade_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/upgrade/types\xc8\xe1\x1e\x00'
    _PLAN.fields_by_name['time']._options = None
    _PLAN.fields_by_name['time']._serialized_options = b'\x18\x01\x90\xdf\x1f\x01\xc8\xde\x1f\x00'
    _PLAN.fields_by_name['upgraded_client_state']._options = None
    _PLAN.fields_by_name['upgraded_client_state']._serialized_options = b'\x18\x01\xf2\xde\x1f\x1cyaml:"upgraded_client_state"'
    _PLAN._options = None
    _PLAN._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _SOFTWAREUPGRADEPROPOSAL.fields_by_name['plan']._options = None
    _SOFTWAREUPGRADEPROPOSAL.fields_by_name['plan']._serialized_options = b'\xc8\xde\x1f\x00'
    _SOFTWAREUPGRADEPROPOSAL._options = None
    _SOFTWAREUPGRADEPROPOSAL._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _CANCELSOFTWAREUPGRADEPROPOSAL._options = None
    _CANCELSOFTWAREUPGRADEPROPOSAL._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _MODULEVERSION._options = None
    _MODULEVERSION._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x01'
    _PLAN._serialized_start = 147
    _PLAN._serialized_end = 350
    _SOFTWAREUPGRADEPROPOSAL._serialized_start = 352
    _SOFTWAREUPGRADEPROPOSAL._serialized_end = 473
    _CANCELSOFTWAREUPGRADEPROPOSAL._serialized_start = 475
    _CANCELSOFTWAREUPGRADEPROPOSAL._serialized_end = 552
    _MODULEVERSION._serialized_start = 554
    _MODULEVERSION._serialized_end = 610




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.node.v2 import node_pb2 as sentinel_dot_node_dot_v2_dot_node__pb2
from ....sentinel.node.v2 import params_pb2 as sentinel_dot_node_dot_v2_dot_params__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/node/v2/genesis.proto\x12\x10sentinel.node.v2\x1a\x14gogoproto/gogo.proto\x1a\x1bsentinel/node/v2/node.proto\x1a\x1dsentinel/node/v2/params.proto"k\n\x0cGenesisState\x12+\n\x05nodes\x18\x01 \x03(\x0b2\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\x12.\n\x06params\x18\x02 \x01(\x0b2\x18.sentinel.node.v2.ParamsB\x04\xc8\xde\x1f\x00B7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _GENESISSTATE.fields_by_name['nodes']._options = None
    _GENESISSTATE.fields_by_name['nodes']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 134
    _GENESISSTATE._serialized_end = 241




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ...tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/types/canonical.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto"i\n\x10CanonicalBlockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12G\n\x0fpart_set_header\x18\x02 \x01(\x0b2(.tendermint.types.CanonicalPartSetHeaderB\x04\xc8\xde\x1f\x00"5\n\x16CanonicalPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04hash\x18\x02 \x01(\x0c"\x9d\x02\n\x11CanonicalProposal\x12-\n\x04type\x18\x01 \x01(\x0e2\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x1f\n\tpol_round\x18\x04 \x01(\x03B\x0c\xe2\xde\x1f\x08POLRound\x12A\n\x08block_id\x18\x05 \x01(\x0b2".tendermint.types.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07BlockID\x127\n\ttimestamp\x18\x06 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08chain_id\x18\x07 \x01(\tB\x0b\xe2\xde\x1f\x07ChainID"\xf8\x01\n\rCanonicalVote\x12-\n\x04type\x18\x01 \x01(\x0e2\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12A\n\x08block_id\x18\x04 \x01(\x0b2".tendermint.types.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07BlockID\x127\n\ttimestamp\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08chain_id\x18\x06 \x01(\tB\x0b\xe2\xde\x1f\x07ChainIDB9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.canonical_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
    _CANONICALBLOCKID.fields_by_name['part_set_header']._options = None
    _CANONICALBLOCKID.fields_by_name['part_set_header']._serialized_options = b'\xc8\xde\x1f\x00'
    _CANONICALPROPOSAL.fields_by_name['pol_round']._options = None
    _CANONICALPROPOSAL.fields_by_name['pol_round']._serialized_options = b'\xe2\xde\x1f\x08POLRound'
    _CANONICALPROPOSAL.fields_by_name['block_id']._options = None
    _CANONICALPROPOSAL.fields_by_name['block_id']._serialized_options = b'\xe2\xde\x1f\x07BlockID'
    _CANONICALPROPOSAL.fields_by_name['timestamp']._options = None
    _CANONICALPROPOSAL.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _CANONICALPROPOSAL.fields_by_name['chain_id']._options = None
    _CANONICALPROPOSAL.fields_by_name['chain_id']._serialized_options = b'\xe2\xde\x1f\x07ChainID'
    _CANONICALVOTE.fields_by_name['block_id']._options = None
    _CANONICALVOTE.fields_by_name['block_id']._serialized_options = b'\xe2\xde\x1f\x07BlockID'
    _CANONICALVOTE.fields_by_name['timestamp']._options = None
    _CANONICALVOTE.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _CANONICALVOTE.fields_by_name['chain_id']._options = None
    _CANONICALVOTE.fields_by_name['chain_id']._serialized_options = b'\xe2\xde\x1f\x07ChainID'
    _CANONICALBLOCKID._serialized_start = 139
    _CANONICALBLOCKID._serialized_end = 244
    _CANONICALPARTSETHEADER._serialized_start = 246
    _CANONICALPARTSETHEADER._serialized_end = 299
    _CANONICALPROPOSAL._serialized_start = 302
    _CANONICALPROPOSAL._serialized_end = 587
    _CANONICALVOTE._serialized_start = 590
    _CANONICALVOTE._serialized_end = 838




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class EventDataRoundState(_message.Message):
    __slots__ = ['height', 'round', 'step']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    step: str

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., step: _Optional[str]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class DenomTrace(_message.Message):
    __slots__ = ['base_denom', 'path']
    BASE_DENOM_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    base_denom: str
    path: str

    def __init__(self, path: _Optional[str]=..., base_denom: _Optional[str]=...) -> None:
        ...

class Params(_message.Message):
    __slots__ = ['receive_enabled', 'send_enabled']
    RECEIVE_ENABLED_FIELD_NUMBER: _ClassVar[int]
    SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    receive_enabled: bool
    send_enabled: bool

    def __init__(self, send_enabled: bool=..., receive_enabled: bool=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/statesync/types.proto\x12\x14tendermint.statesync"\x98\x02\n\x07Message\x12C\n\x11snapshots_request\x18\x01 \x01(\x0b2&.tendermint.statesync.SnapshotsRequestH\x00\x12E\n\x12snapshots_response\x18\x02 \x01(\x0b2\'.tendermint.statesync.SnapshotsResponseH\x00\x12;\n\rchunk_request\x18\x03 \x01(\x0b2".tendermint.statesync.ChunkRequestH\x00\x12=\n\x0echunk_response\x18\x04 \x01(\x0b2#.tendermint.statesync.ChunkResponseH\x00B\x05\n\x03sum"\x12\n\x10SnapshotsRequest"c\n\x11SnapshotsResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06format\x18\x02 \x01(\r\x12\x0e\n\x06chunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c"=\n\x0cChunkRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06format\x18\x02 \x01(\r\x12\r\n\x05index\x18\x03 \x01(\r"^\n\rChunkResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06format\x18\x02 \x01(\r\x12\r\n\x05index\x18\x03 \x01(\r\x12\r\n\x05chunk\x18\x04 \x01(\x0c\x12\x0f\n\x07missing\x18\x05 \x01(\x08B=Z;github.com/tendermint/tendermint/proto/tendermint/statesyncb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.statesync.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z;github.com/tendermint/tendermint/proto/tendermint/statesync'
    _MESSAGE._serialized_start = 59
    _MESSAGE._serialized_end = 339
    _SNAPSHOTSREQUEST._serialized_start = 341
    _SNAPSHOTSREQUEST._serialized_end = 359
    _SNAPSHOTSRESPONSE._serialized_start = 361
    _SNAPSHOTSRESPONSE._serialized_end = 460
    _CHUNKREQUEST._serialized_start = 462
    _CHUNKREQUEST._serialized_end = 523
    _CHUNKRESPONSE._serialized_start = 525
    _CHUNKRESPONSE._serialized_end = 619




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor
TYPE_NODE: SubscriptionType
TYPE_PLAN: SubscriptionType
TYPE_UNSPECIFIED: SubscriptionType

class BaseSubscription(_message.Message):
    __slots__ = ['address', 'expiry_at', 'id', 'status', 'status_at']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    expiry_at: _timestamp_pb2.Timestamp
    id: int
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp

    def __init__(self, id: _Optional[int]=..., address: _Optional[str]=..., expiry_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., status_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...

class NodeSubscription(_message.Message):
    __slots__ = ['base', 'deposit', 'gigabytes', 'hours', 'node_address']
    BASE_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    GIGABYTES_FIELD_NUMBER: _ClassVar[int]
    HOURS_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    base: BaseSubscription
    deposit: _coin_pb2.Coin
    gigabytes: int
    hours: int
    node_address: str

    def __init__(self, base: _Optional[_Union[(BaseSubscription, _Mapping)]]=..., node_address: _Optional[str]=..., gigabytes: _Optional[int]=..., hours: _Optional[int]=..., deposit: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...

class PlanSubscription(_message.Message):
    __slots__ = ['base', 'denom', 'plan_id']
    BASE_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    base: BaseSubscription
    denom: str
    plan_id: int

    def __init__(self, base: _Optional[_Union[(BaseSubscription, _Mapping)]]=..., plan_id: _Optional[int]=..., denom: _Optional[str]=...) -> None:
        ...

class SubscriptionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




from ibc.core.client.v1 import client_pb2 as _client_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisMetadata(_message.Message):
    __slots__ = ['key', 'value']
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes

    def __init__(self, key: _Optional[bytes]=..., value: _Optional[bytes]=...) -> None:
        ...

class GenesisState(_message.Message):
    __slots__ = ['clients', 'clients_consensus', 'clients_metadata', 'create_localhost', 'next_client_sequence', 'params']
    CLIENTS_CONSENSUS_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_METADATA_FIELD_NUMBER: _ClassVar[int]
    CREATE_LOCALHOST_FIELD_NUMBER: _ClassVar[int]
    NEXT_CLIENT_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    clients: _containers.RepeatedCompositeFieldContainer[_client_pb2.IdentifiedClientState]
    clients_consensus: _containers.RepeatedCompositeFieldContainer[_client_pb2.ClientConsensusStates]
    clients_metadata: _containers.RepeatedCompositeFieldContainer[IdentifiedGenesisMetadata]
    create_localhost: bool
    next_client_sequence: int
    params: _client_pb2.Params

    def __init__(self, clients: _Optional[_Iterable[_Union[(_client_pb2.IdentifiedClientState, _Mapping)]]]=..., clients_consensus: _Optional[_Iterable[_Union[(_client_pb2.ClientConsensusStates, _Mapping)]]]=..., clients_metadata: _Optional[_Iterable[_Union[(IdentifiedGenesisMetadata, _Mapping)]]]=..., params: _Optional[_Union[(_client_pb2.Params, _Mapping)]]=..., create_localhost: bool=..., next_client_sequence: _Optional[int]=...) -> None:
        ...

class IdentifiedGenesisMetadata(_message.Message):
    __slots__ = ['client_id', 'client_metadata']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_METADATA_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_metadata: _containers.RepeatedCompositeFieldContainer[GenesisMetadata]

    def __init__(self, client_id: _Optional[str]=..., client_metadata: _Optional[_Iterable[_Union[(GenesisMetadata, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.capability.v1beta1 import capability_pb2 as cosmos_dot_capability_dot_v1beta1_dot_capability__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/capability/v1beta1/genesis.proto\x12\x19cosmos.capability.v1beta1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/capability/v1beta1/capability.proto"~\n\rGenesisOwners\x12\r\n\x05index\x18\x01 \x01(\x04\x12^\n\x0cindex_owners\x18\x02 \x01(\x0b2+.cosmos.capability.v1beta1.CapabilityOwnersB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"index_owners""]\n\x0cGenesisState\x12\r\n\x05index\x18\x01 \x01(\x04\x12>\n\x06owners\x18\x02 \x03(\x0b2(.cosmos.capability.v1beta1.GenesisOwnersB\x04\xc8\xde\x1f\x00B1Z/github.com/cosmos/cosmos-sdk/x/capability/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.capability.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z/github.com/cosmos/cosmos-sdk/x/capability/types'
    _GENESISOWNERS.fields_by_name['index_owners']._options = None
    _GENESISOWNERS.fields_by_name['index_owners']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"index_owners"'
    _GENESISSTATE.fields_by_name['owners']._options = None
    _GENESISSTATE.fields_by_name['owners']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISOWNERS._serialized_start = 136
    _GENESISOWNERS._serialized_end = 262
    _GENESISSTATE._serialized_start = 264
    _GENESISSTATE._serialized_end = 357




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....sentinel.subscription.v2 import allocation_pb2 as sentinel_dot_subscription_dot_v2_dot_allocation__pb2
from ....sentinel.subscription.v2 import params_pb2 as sentinel_dot_subscription_dot_v2_dot_params__pb2
from ....sentinel.subscription.v2 import payout_pb2 as sentinel_dot_subscription_dot_v2_dot_payout__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sentinel/subscription/v2/querier.proto\x12\x18sentinel.subscription.v2\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a)sentinel/subscription/v2/allocation.proto\x1a%sentinel/subscription/v2/params.proto\x1a%sentinel/subscription/v2/payout.proto"W\n\x19QuerySubscriptionsRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"r\n#QuerySubscriptionsForAccountRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"o\n QuerySubscriptionsForNodeRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"j\n QuerySubscriptionsForPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"&\n\x18QuerySubscriptionRequest\x12\n\n\x02id\x18\x01 \x01(\x04"5\n\x16QueryAllocationRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07address\x18\x02 \x01(\t"a\n\x17QueryAllocationsRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"Q\n\x13QueryPayoutsRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"l\n\x1dQueryPayoutsForAccountRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"i\n\x1aQueryPayoutsForNodeRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest" \n\x12QueryPayoutRequest\x12\n\n\x02id\x18\x01 \x01(\x04"\x14\n\x12QueryParamsRequest"\x86\x01\n\x1aQuerySubscriptionsResponse\x12+\n\rsubscriptions\x18\x01 \x03(\x0b2\x14.google.protobuf.Any\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x90\x01\n$QuerySubscriptionsForAccountResponse\x12+\n\rsubscriptions\x18\x01 \x03(\x0b2\x14.google.protobuf.Any\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x8d\x01\n!QuerySubscriptionsForNodeResponse\x12+\n\rsubscriptions\x18\x01 \x03(\x0b2\x14.google.protobuf.Any\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x8d\x01\n!QuerySubscriptionsForPlanResponse\x12+\n\rsubscriptions\x18\x01 \x03(\x0b2\x14.google.protobuf.Any\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"G\n\x19QuerySubscriptionResponse\x12*\n\x0csubscription\x18\x01 \x01(\x0b2\x14.google.protobuf.Any"Y\n\x17QueryAllocationResponse\x12>\n\nallocation\x18\x01 \x01(\x0b2$.sentinel.subscription.v2.AllocationB\x04\xc8\xde\x1f\x00"\x98\x01\n\x18QueryAllocationsResponse\x12?\n\x0ballocations\x18\x01 \x03(\x0b2$.sentinel.subscription.v2.AllocationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x8c\x01\n\x14QueryPayoutsResponse\x127\n\x07payouts\x18\x01 \x03(\x0b2 .sentinel.subscription.v2.PayoutB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x96\x01\n\x1eQueryPayoutsForAccountResponse\x127\n\x07payouts\x18\x01 \x03(\x0b2 .sentinel.subscription.v2.PayoutB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x93\x01\n\x1bQueryPayoutsForNodeResponse\x127\n\x07payouts\x18\x01 \x03(\x0b2 .sentinel.subscription.v2.PayoutB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"M\n\x13QueryPayoutResponse\x126\n\x06payout\x18\x01 \x01(\x0b2 .sentinel.subscription.v2.PayoutB\x04\xc8\xde\x1f\x00"M\n\x13QueryParamsResponse\x126\n\x06params\x18\x01 \x01(\x0b2 .sentinel.subscription.v2.ParamsB\x04\xc8\xde\x1f\x002\xb8\x10\n\x0cQueryService\x12\xa0\x01\n\x12QuerySubscriptions\x123.sentinel.subscription.v2.QuerySubscriptionsRequest\x1a4.sentinel.subscription.v2.QuerySubscriptionsResponse"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/subscriptions\x12\xd1\x01\n\x1cQuerySubscriptionsForAccount\x12=.sentinel.subscription.v2.QuerySubscriptionsForAccountRequest\x1a>.sentinel.subscription.v2.QuerySubscriptionsForAccountResponse"2\x82\xd3\xe4\x93\x02,\x12*/sentinel/accounts/{address}/subscriptions\x12\xc5\x01\n\x19QuerySubscriptionsForNode\x12:.sentinel.subscription.v2.QuerySubscriptionsForNodeRequest\x1a;.sentinel.subscription.v2.QuerySubscriptionsForNodeResponse"/\x82\xd3\xe4\x93\x02)\x12\'/sentinel/nodes/{address}/subscriptions\x12\xc0\x01\n\x19QuerySubscriptionsForPlan\x12:.sentinel.subscription.v2.QuerySubscriptionsForPlanRequest\x1a;.sentinel.subscription.v2.QuerySubscriptionsForPlanResponse"*\x82\xd3\xe4\x93\x02$\x12"/sentinel/plans/{id}/subscriptions\x12\xa2\x01\n\x11QuerySubscription\x122.sentinel.subscription.v2.QuerySubscriptionRequest\x1a3.sentinel.subscription.v2.QuerySubscriptionResponse"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/sentinel/subscriptions/{id}\x12\xab\x01\n\x10QueryAllocations\x121.sentinel.subscription.v2.QueryAllocationsRequest\x1a2.sentinel.subscription.v2.QueryAllocationsResponse"0\x82\xd3\xe4\x93\x02*\x12(/sentinel/subscriptions/{id}/allocations\x12\xb2\x01\n\x0fQueryAllocation\x120.sentinel.subscription.v2.QueryAllocationRequest\x1a1.sentinel.subscription.v2.QueryAllocationResponse":\x82\xd3\xe4\x93\x024\x122/sentinel/subscriptions/{id}/allocations/{address}\x12\x88\x01\n\x0cQueryPayouts\x12-.sentinel.subscription.v2.QueryPayoutsRequest\x1a..sentinel.subscription.v2.QueryPayoutsResponse"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/sentinel/payouts\x12\xb9\x01\n\x16QueryPayoutsForAccount\x127.sentinel.subscription.v2.QueryPayoutsForAccountRequest\x1a8.sentinel.subscription.v2.QueryPayoutsForAccountResponse",\x82\xd3\xe4\x93\x02&\x12$/sentinel/accounts/{address}/payouts\x12\xad\x01\n\x13QueryPayoutsForNode\x124.sentinel.subscription.v2.QueryPayoutsForNodeRequest\x1a5.sentinel.subscription.v2.QueryPayoutsForNodeResponse")\x82\xd3\xe4\x93\x02#\x12!/sentinel/nodes/{address}/payouts\x12\x8a\x01\n\x0bQueryPayout\x12,.sentinel.subscription.v2.QueryPayoutRequest\x1a-.sentinel.subscription.v2.QueryPayoutResponse"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/sentinel/payouts/{id}\x12\x99\x01\n\x0bQueryParams\x12,.sentinel.subscription.v2.QueryParamsRequest\x1a-.sentinel.subscription.v2.QueryParamsResponse"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/modules/subscription/paramsB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.querier_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUERYALLOCATIONRESPONSE.fields_by_name['allocation']._options = None
    _QUERYALLOCATIONRESPONSE.fields_by_name['allocation']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYALLOCATIONSRESPONSE.fields_by_name['allocations']._options = None
    _QUERYALLOCATIONSRESPONSE.fields_by_name['allocations']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPAYOUTSRESPONSE.fields_by_name['payouts']._options = None
    _QUERYPAYOUTSRESPONSE.fields_by_name['payouts']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPAYOUTSFORACCOUNTRESPONSE.fields_by_name['payouts']._options = None
    _QUERYPAYOUTSFORACCOUNTRESPONSE.fields_by_name['payouts']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPAYOUTSFORNODERESPONSE.fields_by_name['payouts']._options = None
    _QUERYPAYOUTSFORNODERESPONSE.fields_by_name['payouts']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPAYOUTRESPONSE.fields_by_name['payout']._options = None
    _QUERYPAYOUTRESPONSE.fields_by_name['payout']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSERVICE.methods_by_name['QuerySubscriptions']._options = None
    _QUERYSERVICE.methods_by_name['QuerySubscriptions']._serialized_options = b'\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/subscriptions'
    _QUERYSERVICE.methods_by_name['QuerySubscriptionsForAccount']._options = None
    _QUERYSERVICE.methods_by_name['QuerySubscriptionsForAccount']._serialized_options = b'\x82\xd3\xe4\x93\x02,\x12*/sentinel/accounts/{address}/subscriptions'
    _QUERYSERVICE.methods_by_name['QuerySubscriptionsForNode']._options = None
    _QUERYSERVICE.methods_by_name['QuerySubscriptionsForNode']._serialized_options = b"\x82\xd3\xe4\x93\x02)\x12'/sentinel/nodes/{address}/subscriptions"
    _QUERYSERVICE.methods_by_name['QuerySubscriptionsForPlan']._options = None
    _QUERYSERVICE.methods_by_name['QuerySubscriptionsForPlan']._serialized_options = b'\x82\xd3\xe4\x93\x02$\x12"/sentinel/plans/{id}/subscriptions'
    _QUERYSERVICE.methods_by_name['QuerySubscription']._options = None
    _QUERYSERVICE.methods_by_name['QuerySubscription']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1e\x12\x1c/sentinel/subscriptions/{id}'
    _QUERYSERVICE.methods_by_name['QueryAllocations']._options = None
    _QUERYSERVICE.methods_by_name['QueryAllocations']._serialized_options = b'\x82\xd3\xe4\x93\x02*\x12(/sentinel/subscriptions/{id}/allocations'
    _QUERYSERVICE.methods_by_name['QueryAllocation']._options = None
    _QUERYSERVICE.methods_by_name['QueryAllocation']._serialized_options = b'\x82\xd3\xe4\x93\x024\x122/sentinel/subscriptions/{id}/allocations/{address}'
    _QUERYSERVICE.methods_by_name['QueryPayouts']._options = None
    _QUERYSERVICE.methods_by_name['QueryPayouts']._serialized_options = b'\x82\xd3\xe4\x93\x02\x13\x12\x11/sentinel/payouts'
    _QUERYSERVICE.methods_by_name['QueryPayoutsForAccount']._options = None
    _QUERYSERVICE.methods_by_name['QueryPayoutsForAccount']._serialized_options = b'\x82\xd3\xe4\x93\x02&\x12$/sentinel/accounts/{address}/payouts'
    _QUERYSERVICE.methods_by_name['QueryPayoutsForNode']._options = None
    _QUERYSERVICE.methods_by_name['QueryPayoutsForNode']._serialized_options = b'\x82\xd3\xe4\x93\x02#\x12!/sentinel/nodes/{address}/payouts'
    _QUERYSERVICE.methods_by_name['QueryPayout']._options = None
    _QUERYSERVICE.methods_by_name['QueryPayout']._serialized_options = b'\x82\xd3\xe4\x93\x02\x18\x12\x16/sentinel/payouts/{id}'
    _QUERYSERVICE.methods_by_name['QueryParams']._options = None
    _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b"\x82\xd3\xe4\x93\x02'\x12%/sentinel/modules/subscription/params"
    _QUERYSUBSCRIPTIONSREQUEST._serialized_start = 312
    _QUERYSUBSCRIPTIONSREQUEST._serialized_end = 399
    _QUERYSUBSCRIPTIONSFORACCOUNTREQUEST._serialized_start = 401
    _QUERYSUBSCRIPTIONSFORACCOUNTREQUEST._serialized_end = 515
    _QUERYSUBSCRIPTIONSFORNODEREQUEST._serialized_start = 517
    _QUERYSUBSCRIPTIONSFORNODEREQUEST._serialized_end = 628
    _QUERYSUBSCRIPTIONSFORPLANREQUEST._serialized_start = 630
    _QUERYSUBSCRIPTIONSFORPLANREQUEST._serialized_end = 736
    _QUERYSUBSCRIPTIONREQUEST._serialized_start = 738
    _QUERYSUBSCRIPTIONREQUEST._serialized_end = 776
    _QUERYALLOCATIONREQUEST._serialized_start = 778
    _QUERYALLOCATIONREQUEST._serialized_end = 831
    _QUERYALLOCATIONSREQUEST._serialized_start = 833
    _QUERYALLOCATIONSREQUEST._serialized_end = 930
    _QUERYPAYOUTSREQUEST._serialized_start = 932
    _QUERYPAYOUTSREQUEST._serialized_end = 1013
    _QUERYPAYOUTSFORACCOUNTREQUEST._serialized_start = 1015
    _QUERYPAYOUTSFORACCOUNTREQUEST._serialized_end = 1123
    _QUERYPAYOUTSFORNODEREQUEST._serialized_start = 1125
    _QUERYPAYOUTSFORNODEREQUEST._serialized_end = 1230
    _QUERYPAYOUTREQUEST._serialized_start = 1232
    _QUERYPAYOUTREQUEST._serialized_end = 1264
    _QUERYPARAMSREQUEST._serialized_start = 1266
    _QUERYPARAMSREQUEST._serialized_end = 1286
    _QUERYSUBSCRIPTIONSRESPONSE._serialized_start = 1289
    _QUERYSUBSCRIPTIONSRESPONSE._serialized_end = 1423
    _QUERYSUBSCRIPTIONSFORACCOUNTRESPONSE._serialized_start = 1426
    _QUERYSUBSCRIPTIONSFORACCOUNTRESPONSE._serialized_end = 1570
    _QUERYSUBSCRIPTIONSFORNODERESPONSE._serialized_start = 1573
    _QUERYSUBSCRIPTIONSFORNODERESPONSE._serialized_end = 1714
    _QUERYSUBSCRIPTIONSFORPLANRESPONSE._serialized_start = 1717
    _QUERYSUBSCRIPTIONSFORPLANRESPONSE._serialized_end = 1858
    _QUERYSUBSCRIPTIONRESPONSE._serialized_start = 1860
    _QUERYSUBSCRIPTIONRESPONSE._serialized_end = 1931
    _QUERYALLOCATIONRESPONSE._serialized_start = 1933
    _QUERYALLOCATIONRESPONSE._serialized_end = 2022
    _QUERYALLOCATIONSRESPONSE._serialized_start = 2025
    _QUERYALLOCATIONSRESPONSE._serialized_end = 2177
    _QUERYPAYOUTSRESPONSE._serialized_start = 2180
    _QUERYPAYOUTSRESPONSE._serialized_end = 2320
    _QUERYPAYOUTSFORACCOUNTRESPONSE._serialized_start = 2323
    _QUERYPAYOUTSFORACCOUNTRESPONSE._serialized_end = 2473
    _QUERYPAYOUTSFORNODERESPONSE._serialized_start = 2476
    _QUERYPAYOUTSFORNODERESPONSE._serialized_end = 2623
    _QUERYPAYOUTRESPONSE._serialized_start = 2625
    _QUERYPAYOUTRESPONSE._serialized_end = 2702
    _QUERYPARAMSRESPONSE._serialized_start = 2704
    _QUERYPARAMSRESPONSE._serialized_end = 2781
    _QUERYSERVICE._serialized_start = 2784
    _QUERYSERVICE._serialized_end = 4888




from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.types import types_pb2 as _types_pb2
from tendermint.libs.bits import types_pb2 as _types_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class BlockPart(_message.Message):
    __slots__ = ['height', 'part', 'round']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PART_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    height: int
    part: _types_pb2.Part
    round: int

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., part: _Optional[_Union[(_types_pb2.Part, _Mapping)]]=...) -> None:
        ...

class HasVote(_message.Message):
    __slots__ = ['height', 'index', 'round', 'type']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    height: int
    index: int
    round: int
    type: _types_pb2.SignedMsgType

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., type: _Optional[_Union[(_types_pb2.SignedMsgType, str)]]=..., index: _Optional[int]=...) -> None:
        ...

class Message(_message.Message):
    __slots__ = ['block_part', 'has_vote', 'new_round_step', 'new_valid_block', 'proposal', 'proposal_pol', 'vote', 'vote_set_bits', 'vote_set_maj23']
    BLOCK_PART_FIELD_NUMBER: _ClassVar[int]
    HAS_VOTE_FIELD_NUMBER: _ClassVar[int]
    NEW_ROUND_STEP_FIELD_NUMBER: _ClassVar[int]
    NEW_VALID_BLOCK_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_POL_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    VOTE_SET_BITS_FIELD_NUMBER: _ClassVar[int]
    VOTE_SET_MAJ23_FIELD_NUMBER: _ClassVar[int]
    block_part: BlockPart
    has_vote: HasVote
    new_round_step: NewRoundStep
    new_valid_block: NewValidBlock
    proposal: Proposal
    proposal_pol: ProposalPOL
    vote: Vote
    vote_set_bits: VoteSetBits
    vote_set_maj23: VoteSetMaj23

    def __init__(self, new_round_step: _Optional[_Union[(NewRoundStep, _Mapping)]]=..., new_valid_block: _Optional[_Union[(NewValidBlock, _Mapping)]]=..., proposal: _Optional[_Union[(Proposal, _Mapping)]]=..., proposal_pol: _Optional[_Union[(ProposalPOL, _Mapping)]]=..., block_part: _Optional[_Union[(BlockPart, _Mapping)]]=..., vote: _Optional[_Union[(Vote, _Mapping)]]=..., has_vote: _Optional[_Union[(HasVote, _Mapping)]]=..., vote_set_maj23: _Optional[_Union[(VoteSetMaj23, _Mapping)]]=..., vote_set_bits: _Optional[_Union[(VoteSetBits, _Mapping)]]=...) -> None:
        ...

class NewRoundStep(_message.Message):
    __slots__ = ['height', 'last_commit_round', 'round', 'seconds_since_start_time', 'step']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_ROUND_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    SECONDS_SINCE_START_TIME_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    height: int
    last_commit_round: int
    round: int
    seconds_since_start_time: int
    step: int

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., step: _Optional[int]=..., seconds_since_start_time: _Optional[int]=..., last_commit_round: _Optional[int]=...) -> None:
        ...

class NewValidBlock(_message.Message):
    __slots__ = ['block_part_set_header', 'block_parts', 'height', 'is_commit', 'round']
    BLOCK_PARTS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_PART_SET_HEADER_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    IS_COMMIT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    block_part_set_header: _types_pb2.PartSetHeader
    block_parts: _types_pb2_1.BitArray
    height: int
    is_commit: bool
    round: int

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., block_part_set_header: _Optional[_Union[(_types_pb2.PartSetHeader, _Mapping)]]=..., block_parts: _Optional[_Union[(_types_pb2_1.BitArray, _Mapping)]]=..., is_commit: bool=...) -> None:
        ...

class Proposal(_message.Message):
    __slots__ = ['proposal']
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    proposal: _types_pb2.Proposal

    def __init__(self, proposal: _Optional[_Union[(_types_pb2.Proposal, _Mapping)]]=...) -> None:
        ...

class ProposalPOL(_message.Message):
    __slots__ = ['height', 'proposal_pol', 'proposal_pol_round']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_POL_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_POL_ROUND_FIELD_NUMBER: _ClassVar[int]
    height: int
    proposal_pol: _types_pb2_1.BitArray
    proposal_pol_round: int

    def __init__(self, height: _Optional[int]=..., proposal_pol_round: _Optional[int]=..., proposal_pol: _Optional[_Union[(_types_pb2_1.BitArray, _Mapping)]]=...) -> None:
        ...

class Vote(_message.Message):
    __slots__ = ['vote']
    VOTE_FIELD_NUMBER: _ClassVar[int]
    vote: _types_pb2.Vote

    def __init__(self, vote: _Optional[_Union[(_types_pb2.Vote, _Mapping)]]=...) -> None:
        ...

class VoteSetBits(_message.Message):
    __slots__ = ['block_id', 'height', 'round', 'type', 'votes']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    block_id: _types_pb2.BlockID
    height: int
    round: int
    type: _types_pb2.SignedMsgType
    votes: _types_pb2_1.BitArray

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., type: _Optional[_Union[(_types_pb2.SignedMsgType, str)]]=..., block_id: _Optional[_Union[(_types_pb2.BlockID, _Mapping)]]=..., votes: _Optional[_Union[(_types_pb2_1.BitArray, _Mapping)]]=...) -> None:
        ...

class VoteSetMaj23(_message.Message):
    __slots__ = ['block_id', 'height', 'round', 'type']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    block_id: _types_pb2.BlockID
    height: int
    round: int
    type: _types_pb2.SignedMsgType

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., type: _Optional[_Union[(_types_pb2.SignedMsgType, str)]]=..., block_id: _Optional[_Union[(_types_pb2.BlockID, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from .....ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/channel/v1/tx.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\x1a!ibc/core/channel/v1/channel.proto"\x88\x01\n\x12MsgChannelOpenInit\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x123\n\x07channel\x18\x02 \x01(\x0b2\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"G\n\x1aMsgChannelOpenInitResponse\x12)\n\nchannel_id\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id""\xfd\x02\n\x11MsgChannelOpenTry\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12;\n\x13previous_channel_id\x18\x02 \x01(\tB\x1e\xf2\xde\x1f\x1ayaml:"previous_channel_id"\x123\n\x07channel\x18\x03 \x01(\x0b2\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12=\n\x14counterparty_version\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:"counterparty_version"\x12)\n\nproof_init\x18\x05 \x01(\x0cB\x15\xf2\xde\x1f\x11yaml:"proof_init"\x12M\n\x0cproof_height\x18\x06 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1b\n\x19MsgChannelOpenTryResponse"\xf9\x02\n\x11MsgChannelOpenAck\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id"\x12C\n\x17counterparty_channel_id\x18\x03 \x01(\tB"\xf2\xde\x1f\x1eyaml:"counterparty_channel_id"\x12=\n\x14counterparty_version\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:"counterparty_version"\x12\'\n\tproof_try\x18\x05 \x01(\x0cB\x14\xf2\xde\x1f\x10yaml:"proof_try"\x12M\n\x0cproof_height\x18\x06 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1b\n\x19MsgChannelOpenAckResponse"\xf9\x01\n\x15MsgChannelOpenConfirm\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id"\x12\'\n\tproof_ack\x18\x03 \x01(\x0cB\x14\xf2\xde\x1f\x10yaml:"proof_ack"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1f\n\x1dMsgChannelOpenConfirmResponse"\x7f\n\x13MsgChannelCloseInit\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id"\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1d\n\x1bMsgChannelCloseInitResponse"\xfc\x01\n\x16MsgChannelCloseConfirm\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id"\x12)\n\nproof_init\x18\x03 \x01(\x0cB\x15\xf2\xde\x1f\x11yaml:"proof_init"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00" \n\x1eMsgChannelCloseConfirmResponse"\xe2\x01\n\rMsgRecvPacket\x121\n\x06packet\x18\x01 \x01(\x0b2\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x125\n\x10proof_commitment\x18\x02 \x01(\x0cB\x1b\xf2\xde\x1f\x17yaml:"proof_commitment"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"V\n\x15MsgRecvPacketResponse\x127\n\x06result\x18\x01 \x01(\x0e2\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00"\x9a\x02\n\nMsgTimeout\x121\n\x06packet\x18\x01 \x01(\x0b2\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x125\n\x10proof_unreceived\x18\x02 \x01(\x0cB\x1b\xf2\xde\x1f\x17yaml:"proof_unreceived"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x129\n\x12next_sequence_recv\x18\x04 \x01(\x04B\x1d\xf2\xde\x1f\x19yaml:"next_sequence_recv"\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"S\n\x12MsgTimeoutResponse\x127\n\x06result\x18\x01 \x01(\x0e2\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00"\xce\x02\n\x11MsgTimeoutOnClose\x121\n\x06packet\x18\x01 \x01(\x0b2\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x125\n\x10proof_unreceived\x18\x02 \x01(\x0cB\x1b\xf2\xde\x1f\x17yaml:"proof_unreceived"\x12+\n\x0bproof_close\x18\x03 \x01(\x0cB\x16\xf2\xde\x1f\x12yaml:"proof_close"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x129\n\x12next_sequence_recv\x18\x05 \x01(\x04B\x1d\xf2\xde\x1f\x19yaml:"next_sequence_recv"\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"Z\n\x19MsgTimeoutOnCloseResponse\x127\n\x06result\x18\x01 \x01(\x0e2\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00"\xf6\x01\n\x12MsgAcknowledgement\x121\n\x06packet\x18\x01 \x01(\x0b2\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x17\n\x0facknowledgement\x18\x02 \x01(\x0c\x12+\n\x0bproof_acked\x18\x03 \x01(\x0cB\x16\xf2\xde\x1f\x12yaml:"proof_acked"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"[\n\x1aMsgAcknowledgementResponse\x127\n\x06result\x18\x01 \x01(\x0e2\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00*\x9a\x01\n\x12ResponseResultType\x120\n\x1bRESPONSE_RESULT_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12"\n\x14RESPONSE_RESULT_NOOP\x10\x01\x1a\x08\x8a\x9d \x04NOOP\x12(\n\x17RESPONSE_RESULT_SUCCESS\x10\x02\x1a\x0b\x8a\x9d \x07SUCCESS\x1a\x04\x88\xa3\x1e\x002\xaf\x08\n\x03Msg\x12k\n\x0fChannelOpenInit\x12\'.ibc.core.channel.v1.MsgChannelOpenInit\x1a/.ibc.core.channel.v1.MsgChannelOpenInitResponse\x12h\n\x0eChannelOpenTry\x12&.ibc.core.channel.v1.MsgChannelOpenTry\x1a..ibc.core.channel.v1.MsgChannelOpenTryResponse\x12h\n\x0eChannelOpenAck\x12&.ibc.core.channel.v1.MsgChannelOpenAck\x1a..ibc.core.channel.v1.MsgChannelOpenAckResponse\x12t\n\x12ChannelOpenConfirm\x12*.ibc.core.channel.v1.MsgChannelOpenConfirm\x1a2.ibc.core.channel.v1.MsgChannelOpenConfirmResponse\x12n\n\x10ChannelCloseInit\x12(.ibc.core.channel.v1.MsgChannelCloseInit\x1a0.ibc.core.channel.v1.MsgChannelCloseInitResponse\x12w\n\x13ChannelCloseConfirm\x12+.ibc.core.channel.v1.MsgChannelCloseConfirm\x1a3.ibc.core.channel.v1.MsgChannelCloseConfirmResponse\x12\\\n\nRecvPacket\x12".ibc.core.channel.v1.MsgRecvPacket\x1a*.ibc.core.channel.v1.MsgRecvPacketResponse\x12S\n\x07Timeout\x12\x1f.ibc.core.channel.v1.MsgTimeout\x1a\'.ibc.core.channel.v1.MsgTimeoutResponse\x12h\n\x0eTimeoutOnClose\x12&.ibc.core.channel.v1.MsgTimeoutOnClose\x1a..ibc.core.channel.v1.MsgTimeoutOnCloseResponse\x12k\n\x0fAcknowledgement\x12\'.ibc.core.channel.v1.MsgAcknowledgement\x1a/.ibc.core.channel.v1.MsgAcknowledgementResponseB;Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/types'
    _RESPONSERESULTTYPE._options = None
    _RESPONSERESULTTYPE._serialized_options = b'\x88\xa3\x1e\x00'
    _RESPONSERESULTTYPE.values_by_name['RESPONSE_RESULT_UNSPECIFIED']._options = None
    _RESPONSERESULTTYPE.values_by_name['RESPONSE_RESULT_UNSPECIFIED']._serialized_options = b'\x8a\x9d \x0bUNSPECIFIED'
    _RESPONSERESULTTYPE.values_by_name['RESPONSE_RESULT_NOOP']._options = None
    _RESPONSERESULTTYPE.values_by_name['RESPONSE_RESULT_NOOP']._serialized_options = b'\x8a\x9d \x04NOOP'
    _RESPONSERESULTTYPE.values_by_name['RESPONSE_RESULT_SUCCESS']._options = None
    _RESPONSERESULTTYPE.values_by_name['RESPONSE_RESULT_SUCCESS']._serialized_options = b'\x8a\x9d \x07SUCCESS'
    _MSGCHANNELOPENINIT.fields_by_name['port_id']._options = None
    _MSGCHANNELOPENINIT.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _MSGCHANNELOPENINIT.fields_by_name['channel']._options = None
    _MSGCHANNELOPENINIT.fields_by_name['channel']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGCHANNELOPENINIT._options = None
    _MSGCHANNELOPENINIT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGCHANNELOPENINITRESPONSE.fields_by_name['channel_id']._options = None
    _MSGCHANNELOPENINITRESPONSE.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _MSGCHANNELOPENTRY.fields_by_name['port_id']._options = None
    _MSGCHANNELOPENTRY.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._options = None
    _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._serialized_options = b'\xf2\xde\x1f\x1ayaml:"previous_channel_id"'
    _MSGCHANNELOPENTRY.fields_by_name['channel']._options = None
    _MSGCHANNELOPENTRY.fields_by_name['channel']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGCHANNELOPENTRY.fields_by_name['counterparty_version']._options = None
    _MSGCHANNELOPENTRY.fields_by_name['counterparty_version']._serialized_options = b'\xf2\xde\x1f\x1byaml:"counterparty_version"'
    _MSGCHANNELOPENTRY.fields_by_name['proof_init']._options = None
    _MSGCHANNELOPENTRY.fields_by_name['proof_init']._serialized_options = b'\xf2\xde\x1f\x11yaml:"proof_init"'
    _MSGCHANNELOPENTRY.fields_by_name['proof_height']._options = None
    _MSGCHANNELOPENTRY.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGCHANNELOPENTRY._options = None
    _MSGCHANNELOPENTRY._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGCHANNELOPENACK.fields_by_name['port_id']._options = None
    _MSGCHANNELOPENACK.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _MSGCHANNELOPENACK.fields_by_name['channel_id']._options = None
    _MSGCHANNELOPENACK.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _MSGCHANNELOPENACK.fields_by_name['counterparty_channel_id']._options = None
    _MSGCHANNELOPENACK.fields_by_name['counterparty_channel_id']._serialized_options = b'\xf2\xde\x1f\x1eyaml:"counterparty_channel_id"'
    _MSGCHANNELOPENACK.fields_by_name['counterparty_version']._options = None
    _MSGCHANNELOPENACK.fields_by_name['counterparty_version']._serialized_options = b'\xf2\xde\x1f\x1byaml:"counterparty_version"'
    _MSGCHANNELOPENACK.fields_by_name['proof_try']._options = None
    _MSGCHANNELOPENACK.fields_by_name['proof_try']._serialized_options = b'\xf2\xde\x1f\x10yaml:"proof_try"'
    _MSGCHANNELOPENACK.fields_by_name['proof_height']._options = None
    _MSGCHANNELOPENACK.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGCHANNELOPENACK._options = None
    _MSGCHANNELOPENACK._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGCHANNELOPENCONFIRM.fields_by_name['port_id']._options = None
    _MSGCHANNELOPENCONFIRM.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _MSGCHANNELOPENCONFIRM.fields_by_name['channel_id']._options = None
    _MSGCHANNELOPENCONFIRM.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _MSGCHANNELOPENCONFIRM.fields_by_name['proof_ack']._options = None
    _MSGCHANNELOPENCONFIRM.fields_by_name['proof_ack']._serialized_options = b'\xf2\xde\x1f\x10yaml:"proof_ack"'
    _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._options = None
    _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGCHANNELOPENCONFIRM._options = None
    _MSGCHANNELOPENCONFIRM._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGCHANNELCLOSEINIT.fields_by_name['port_id']._options = None
    _MSGCHANNELCLOSEINIT.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _MSGCHANNELCLOSEINIT.fields_by_name['channel_id']._options = None
    _MSGCHANNELCLOSEINIT.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _MSGCHANNELCLOSEINIT._options = None
    _MSGCHANNELCLOSEINIT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGCHANNELCLOSECONFIRM.fields_by_name['port_id']._options = None
    _MSGCHANNELCLOSECONFIRM.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _MSGCHANNELCLOSECONFIRM.fields_by_name['channel_id']._options = None
    _MSGCHANNELCLOSECONFIRM.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_init']._options = None
    _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_init']._serialized_options = b'\xf2\xde\x1f\x11yaml:"proof_init"'
    _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._options = None
    _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGCHANNELCLOSECONFIRM._options = None
    _MSGCHANNELCLOSECONFIRM._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGRECVPACKET.fields_by_name['packet']._options = None
    _MSGRECVPACKET.fields_by_name['packet']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGRECVPACKET.fields_by_name['proof_commitment']._options = None
    _MSGRECVPACKET.fields_by_name['proof_commitment']._serialized_options = b'\xf2\xde\x1f\x17yaml:"proof_commitment"'
    _MSGRECVPACKET.fields_by_name['proof_height']._options = None
    _MSGRECVPACKET.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGRECVPACKET._options = None
    _MSGRECVPACKET._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGRECVPACKETRESPONSE._options = None
    _MSGRECVPACKETRESPONSE._serialized_options = b'\x88\xa0\x1f\x00'
    _MSGTIMEOUT.fields_by_name['packet']._options = None
    _MSGTIMEOUT.fields_by_name['packet']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGTIMEOUT.fields_by_name['proof_unreceived']._options = None
    _MSGTIMEOUT.fields_by_name['proof_unreceived']._serialized_options = b'\xf2\xde\x1f\x17yaml:"proof_unreceived"'
    _MSGTIMEOUT.fields_by_name['proof_height']._options = None
    _MSGTIMEOUT.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGTIMEOUT.fields_by_name['next_sequence_recv']._options = None
    _MSGTIMEOUT.fields_by_name['next_sequence_recv']._serialized_options = b'\xf2\xde\x1f\x19yaml:"next_sequence_recv"'
    _MSGTIMEOUT._options = None
    _MSGTIMEOUT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGTIMEOUTRESPONSE._options = None
    _MSGTIMEOUTRESPONSE._serialized_options = b'\x88\xa0\x1f\x00'
    _MSGTIMEOUTONCLOSE.fields_by_name['packet']._options = None
    _MSGTIMEOUTONCLOSE.fields_by_name['packet']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGTIMEOUTONCLOSE.fields_by_name['proof_unreceived']._options = None
    _MSGTIMEOUTONCLOSE.fields_by_name['proof_unreceived']._serialized_options = b'\xf2\xde\x1f\x17yaml:"proof_unreceived"'
    _MSGTIMEOUTONCLOSE.fields_by_name['proof_close']._options = None
    _MSGTIMEOUTONCLOSE.fields_by_name['proof_close']._serialized_options = b'\xf2\xde\x1f\x12yaml:"proof_close"'
    _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._options = None
    _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGTIMEOUTONCLOSE.fields_by_name['next_sequence_recv']._options = None
    _MSGTIMEOUTONCLOSE.fields_by_name['next_sequence_recv']._serialized_options = b'\xf2\xde\x1f\x19yaml:"next_sequence_recv"'
    _MSGTIMEOUTONCLOSE._options = None
    _MSGTIMEOUTONCLOSE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGTIMEOUTONCLOSERESPONSE._options = None
    _MSGTIMEOUTONCLOSERESPONSE._serialized_options = b'\x88\xa0\x1f\x00'
    _MSGACKNOWLEDGEMENT.fields_by_name['packet']._options = None
    _MSGACKNOWLEDGEMENT.fields_by_name['packet']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGACKNOWLEDGEMENT.fields_by_name['proof_acked']._options = None
    _MSGACKNOWLEDGEMENT.fields_by_name['proof_acked']._serialized_options = b'\xf2\xde\x1f\x12yaml:"proof_acked"'
    _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._options = None
    _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"proof_height"\xc8\xde\x1f\x00'
    _MSGACKNOWLEDGEMENT._options = None
    _MSGACKNOWLEDGEMENT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGACKNOWLEDGEMENTRESPONSE._options = None
    _MSGACKNOWLEDGEMENTRESPONSE._serialized_options = b'\x88\xa0\x1f\x00'
    _RESPONSERESULTTYPE._serialized_start = 3370
    _RESPONSERESULTTYPE._serialized_end = 3524
    _MSGCHANNELOPENINIT._serialized_start = 144
    _MSGCHANNELOPENINIT._serialized_end = 280
    _MSGCHANNELOPENINITRESPONSE._serialized_start = 282
    _MSGCHANNELOPENINITRESPONSE._serialized_end = 353
    _MSGCHANNELOPENTRY._serialized_start = 356
    _MSGCHANNELOPENTRY._serialized_end = 737
    _MSGCHANNELOPENTRYRESPONSE._serialized_start = 739
    _MSGCHANNELOPENTRYRESPONSE._serialized_end = 766
    _MSGCHANNELOPENACK._serialized_start = 769
    _MSGCHANNELOPENACK._serialized_end = 1146
    _MSGCHANNELOPENACKRESPONSE._serialized_start = 1148
    _MSGCHANNELOPENACKRESPONSE._serialized_end = 1175
    _MSGCHANNELOPENCONFIRM._serialized_start = 1178
    _MSGCHANNELOPENCONFIRM._serialized_end = 1427
    _MSGCHANNELOPENCONFIRMRESPONSE._serialized_start = 1429
    _MSGCHANNELOPENCONFIRMRESPONSE._serialized_end = 1460
    _MSGCHANNELCLOSEINIT._serialized_start = 1462
    _MSGCHANNELCLOSEINIT._serialized_end = 1589
    _MSGCHANNELCLOSEINITRESPONSE._serialized_start = 1591
    _MSGCHANNELCLOSEINITRESPONSE._serialized_end = 1620
    _MSGCHANNELCLOSECONFIRM._serialized_start = 1623
    _MSGCHANNELCLOSECONFIRM._serialized_end = 1875
    _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_start = 1877
    _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_end = 1909
    _MSGRECVPACKET._serialized_start = 1912
    _MSGRECVPACKET._serialized_end = 2138
    _MSGRECVPACKETRESPONSE._serialized_start = 2140
    _MSGRECVPACKETRESPONSE._serialized_end = 2226
    _MSGTIMEOUT._serialized_start = 2229
    _MSGTIMEOUT._serialized_end = 2511
    _MSGTIMEOUTRESPONSE._serialized_start = 2513
    _MSGTIMEOUTRESPONSE._serialized_end = 2596
    _MSGTIMEOUTONCLOSE._serialized_start = 2599
    _MSGTIMEOUTONCLOSE._serialized_end = 2933
    _MSGTIMEOUTONCLOSERESPONSE._serialized_start = 2935
    _MSGTIMEOUTONCLOSERESPONSE._serialized_end = 3025
    _MSGACKNOWLEDGEMENT._serialized_start = 3028
    _MSGACKNOWLEDGEMENT._serialized_end = 3274
    _MSGACKNOWLEDGEMENTRESPONSE._serialized_start = 3276
    _MSGACKNOWLEDGEMENTRESPONSE._serialized_end = 3367
    _MSG._serialized_start = 3527
    _MSG._serialized_end = 4598




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/gov/v1beta1/genesis.proto\x12\x12cosmos.gov.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ccosmos/gov/v1beta1/gov.proto"\x8f\x04\n\x0cGenesisState\x12=\n\x14starting_proposal_id\x18\x01 \x01(\x04B\x1f\xf2\xde\x1f\x1byaml:"starting_proposal_id"\x12?\n\x08deposits\x18\x02 \x03(\x0b2\x1b.cosmos.gov.v1beta1.DepositB\x10\xaa\xdf\x1f\x08Deposits\xc8\xde\x1f\x00\x126\n\x05votes\x18\x03 \x03(\x0b2\x18.cosmos.gov.v1beta1.VoteB\r\xaa\xdf\x1f\x05Votes\xc8\xde\x1f\x00\x12B\n\tproposals\x18\x04 \x03(\x0b2\x1c.cosmos.gov.v1beta1.ProposalB\x11\xaa\xdf\x1f\tProposals\xc8\xde\x1f\x00\x12X\n\x0edeposit_params\x18\x05 \x01(\x0b2!.cosmos.gov.v1beta1.DepositParamsB\x1d\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:"deposit_params"\x12U\n\rvoting_params\x18\x06 \x01(\x0b2 .cosmos.gov.v1beta1.VotingParamsB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"voting_params"\x12R\n\x0ctally_params\x18\x07 \x01(\x0b2\x1f.cosmos.gov.v1beta1.TallyParamsB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"tally_params"B*Z(github.com/cosmos/cosmos-sdk/x/gov/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/x/gov/types'
    _GENESISSTATE.fields_by_name['starting_proposal_id']._options = None
    _GENESISSTATE.fields_by_name['starting_proposal_id']._serialized_options = b'\xf2\xde\x1f\x1byaml:"starting_proposal_id"'
    _GENESISSTATE.fields_by_name['deposits']._options = None
    _GENESISSTATE.fields_by_name['deposits']._serialized_options = b'\xaa\xdf\x1f\x08Deposits\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['votes']._options = None
    _GENESISSTATE.fields_by_name['votes']._serialized_options = b'\xaa\xdf\x1f\x05Votes\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['proposals']._options = None
    _GENESISSTATE.fields_by_name['proposals']._serialized_options = b'\xaa\xdf\x1f\tProposals\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['deposit_params']._options = None
    _GENESISSTATE.fields_by_name['deposit_params']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:"deposit_params"'
    _GENESISSTATE.fields_by_name['voting_params']._options = None
    _GENESISSTATE.fields_by_name['voting_params']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"voting_params"'
    _GENESISSTATE.fields_by_name['tally_params']._options = None
    _GENESISSTATE.fields_by_name['tally_params']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"tally_params"'
    _GENESISSTATE._serialized_start = 109
    _GENESISSTATE._serialized_end = 636




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.staking.v1beta1 import query_pb2 as cosmos_dot_staking_dot_v1beta1_dot_query__pb2

class QueryStub(object):
    'Query defines the gRPC querier service.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Validators = channel.unary_unary('/cosmos.staking.v1beta1.Query/Validators', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsResponse.FromString)
        self.Validator = channel.unary_unary('/cosmos.staking.v1beta1.Query/Validator', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorResponse.FromString)
        self.ValidatorDelegations = channel.unary_unary('/cosmos.staking.v1beta1.Query/ValidatorDelegations', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsResponse.FromString)
        self.ValidatorUnbondingDelegations = channel.unary_unary('/cosmos.staking.v1beta1.Query/ValidatorUnbondingDelegations', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsResponse.FromString)
        self.Delegation = channel.unary_unary('/cosmos.staking.v1beta1.Query/Delegation', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationResponse.FromString)
        self.UnbondingDelegation = channel.unary_unary('/cosmos.staking.v1beta1.Query/UnbondingDelegation', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationResponse.FromString)
        self.DelegatorDelegations = channel.unary_unary('/cosmos.staking.v1beta1.Query/DelegatorDelegations', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsResponse.FromString)
        self.DelegatorUnbondingDelegations = channel.unary_unary('/cosmos.staking.v1beta1.Query/DelegatorUnbondingDelegations', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsResponse.FromString)
        self.Redelegations = channel.unary_unary('/cosmos.staking.v1beta1.Query/Redelegations', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsResponse.FromString)
        self.DelegatorValidators = channel.unary_unary('/cosmos.staking.v1beta1.Query/DelegatorValidators', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString)
        self.DelegatorValidator = channel.unary_unary('/cosmos.staking.v1beta1.Query/DelegatorValidator', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorResponse.FromString)
        self.HistoricalInfo = channel.unary_unary('/cosmos.staking.v1beta1.Query/HistoricalInfo', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoResponse.FromString)
        self.Pool = channel.unary_unary('/cosmos.staking.v1beta1.Query/Pool', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolResponse.FromString)
        self.Params = channel.unary_unary('/cosmos.staking.v1beta1.Query/Params', request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString)

class QueryServicer(object):
    'Query defines the gRPC querier service.\n    '

    def Validators(self, request, context):
        'Validators queries all validators that match the given status.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Validator(self, request, context):
        'Validator queries validator info for given validator address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorDelegations(self, request, context):
        'ValidatorDelegations queries delegate info for given validator.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorUnbondingDelegations(self, request, context):
        'ValidatorUnbondingDelegations queries unbonding delegations of a validator.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delegation(self, request, context):
        'Delegation queries delegate info for given validator delegator pair.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbondingDelegation(self, request, context):
        'UnbondingDelegation queries unbonding info for given validator delegator\n        pair.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorDelegations(self, request, context):
        'DelegatorDelegations queries all delegations of a given delegator address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorUnbondingDelegations(self, request, context):
        'DelegatorUnbondingDelegations queries all unbonding delegations of a given\n        delegator address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Redelegations(self, request, context):
        'Redelegations queries redelegations of given address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorValidators(self, request, context):
        'DelegatorValidators queries all validators info for given delegator\n        address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorValidator(self, request, context):
        'DelegatorValidator queries validator info for given delegator validator\n        pair.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HistoricalInfo(self, request, context):
        'HistoricalInfo queries the historical info for given height.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pool(self, request, context):
        'Pool queries the pool info.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        'Parameters queries the staking parameters.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Validators': grpc.unary_unary_rpc_method_handler(servicer.Validators, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsResponse.SerializeToString), 'Validator': grpc.unary_unary_rpc_method_handler(servicer.Validator, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorResponse.SerializeToString), 'ValidatorDelegations': grpc.unary_unary_rpc_method_handler(servicer.ValidatorDelegations, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsResponse.SerializeToString), 'ValidatorUnbondingDelegations': grpc.unary_unary_rpc_method_handler(servicer.ValidatorUnbondingDelegations, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsResponse.SerializeToString), 'Delegation': grpc.unary_unary_rpc_method_handler(servicer.Delegation, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationResponse.SerializeToString), 'UnbondingDelegation': grpc.unary_unary_rpc_method_handler(servicer.UnbondingDelegation, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationResponse.SerializeToString), 'DelegatorDelegations': grpc.unary_unary_rpc_method_handler(servicer.DelegatorDelegations, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsResponse.SerializeToString), 'DelegatorUnbondingDelegations': grpc.unary_unary_rpc_method_handler(servicer.DelegatorUnbondingDelegations, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsResponse.SerializeToString), 'Redelegations': grpc.unary_unary_rpc_method_handler(servicer.Redelegations, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsResponse.SerializeToString), 'DelegatorValidators': grpc.unary_unary_rpc_method_handler(servicer.DelegatorValidators, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.SerializeToString), 'DelegatorValidator': grpc.unary_unary_rpc_method_handler(servicer.DelegatorValidator, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorResponse.SerializeToString), 'HistoricalInfo': grpc.unary_unary_rpc_method_handler(servicer.HistoricalInfo, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoResponse.SerializeToString), 'Pool': grpc.unary_unary_rpc_method_handler(servicer.Pool, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolResponse.SerializeToString), 'Params': grpc.unary_unary_rpc_method_handler(servicer.Params, request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString, response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.staking.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service.\n    '

    @staticmethod
    def Validators(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/Validators', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Validator(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/Validator', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/ValidatorDelegations', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorUnbondingDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/ValidatorUnbondingDelegations', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delegation(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/Delegation', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbondingDelegation(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/UnbondingDelegation', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/DelegatorDelegations', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorUnbondingDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/DelegatorUnbondingDelegations', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Redelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/Redelegations', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorValidators(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/DelegatorValidators', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorValidator(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/DelegatorValidator', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HistoricalInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/HistoricalInfo', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Pool(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/Pool', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.staking.v1beta1.Query/Params', cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .....tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from .....tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from .....tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from .....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/tendermint/v1beta1/query.proto\x12\x1ecosmos.base.tendermint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1atendermint/p2p/types.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\x1a*cosmos/base/query/v1beta1/pagination.proto"l\n\x1eGetValidatorSetByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xb3\x01\n\x1fGetValidatorSetByHeightResponse\x12\x14\n\x0cblock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b2).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"Z\n\x1cGetLatestValidatorSetRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xb1\x01\n\x1dGetLatestValidatorSetResponse\x12\x14\n\x0cblock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b2).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"t\n\tValidator\x12\x0f\n\x07address\x18\x01 \x01(\t\x12%\n\x07pub_key\x18\x02 \x01(\x0b2\x14.google.protobuf.Any\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x03\x12\x19\n\x11proposer_priority\x18\x04 \x01(\x03")\n\x17GetBlockByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03"o\n\x18GetBlockByHeightResponse\x12+\n\x08block_id\x18\x01 \x01(\x0b2\x19.tendermint.types.BlockID\x12&\n\x05block\x18\x02 \x01(\x0b2\x17.tendermint.types.Block"\x17\n\x15GetLatestBlockRequest"m\n\x16GetLatestBlockResponse\x12+\n\x08block_id\x18\x01 \x01(\x0b2\x19.tendermint.types.BlockID\x12&\n\x05block\x18\x02 \x01(\x0b2\x17.tendermint.types.Block"\x13\n\x11GetSyncingRequest"%\n\x12GetSyncingResponse\x12\x0f\n\x07syncing\x18\x01 \x01(\x08"\x14\n\x12GetNodeInfoRequest"\x9b\x01\n\x13GetNodeInfoResponse\x12:\n\x11default_node_info\x18\x01 \x01(\x0b2\x1f.tendermint.p2p.DefaultNodeInfo\x12H\n\x13application_version\x18\x02 \x01(\x0b2+.cosmos.base.tendermint.v1beta1.VersionInfo"\xd2\x01\n\x0bVersionInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08app_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x12\n\ngit_commit\x18\x04 \x01(\t\x12\x12\n\nbuild_tags\x18\x05 \x01(\t\x12\x12\n\ngo_version\x18\x06 \x01(\t\x12:\n\nbuild_deps\x18\x07 \x03(\x0b2&.cosmos.base.tendermint.v1beta1.Module\x12\x1a\n\x12cosmos_sdk_version\x18\x08 \x01(\t"4\n\x06Module\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0b\n\x03sum\x18\x03 \x01(\t2\x88\t\n\x07Service\x12\xa9\x01\n\x0bGetNodeInfo\x122.cosmos.base.tendermint.v1beta1.GetNodeInfoRequest\x1a3.cosmos.base.tendermint.v1beta1.GetNodeInfoResponse"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/base/tendermint/v1beta1/node_info\x12\xa4\x01\n\nGetSyncing\x121.cosmos.base.tendermint.v1beta1.GetSyncingRequest\x1a2.cosmos.base.tendermint.v1beta1.GetSyncingResponse"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/base/tendermint/v1beta1/syncing\x12\xb6\x01\n\x0eGetLatestBlock\x125.cosmos.base.tendermint.v1beta1.GetLatestBlockRequest\x1a6.cosmos.base.tendermint.v1beta1.GetLatestBlockResponse"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/base/tendermint/v1beta1/blocks/latest\x12\xbe\x01\n\x10GetBlockByHeight\x127.cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest\x1a8.cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse"7\x82\xd3\xe4\x93\x021\x12//cosmos/base/tendermint/v1beta1/blocks/{height}\x12\xd2\x01\n\x15GetLatestValidatorSet\x12<.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest\x1a=.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse"<\x82\xd3\xe4\x93\x026\x124/cosmos/base/tendermint/v1beta1/validatorsets/latest\x12\xda\x01\n\x17GetValidatorSetByHeight\x12>.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest\x1a?.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse">\x82\xd3\xe4\x93\x028\x126/cosmos/base/tendermint/v1beta1/validatorsets/{height}B4Z2github.com/cosmos/cosmos-sdk/client/grpc/tmserviceb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.tendermint.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/client/grpc/tmservice'
    _SERVICE.methods_by_name['GetNodeInfo']._options = None
    _SERVICE.methods_by_name['GetNodeInfo']._serialized_options = b'\x82\xd3\xe4\x93\x02+\x12)/cosmos/base/tendermint/v1beta1/node_info'
    _SERVICE.methods_by_name['GetSyncing']._options = None
    _SERVICE.methods_by_name['GetSyncing']._serialized_options = b"\x82\xd3\xe4\x93\x02)\x12'/cosmos/base/tendermint/v1beta1/syncing"
    _SERVICE.methods_by_name['GetLatestBlock']._options = None
    _SERVICE.methods_by_name['GetLatestBlock']._serialized_options = b'\x82\xd3\xe4\x93\x02/\x12-/cosmos/base/tendermint/v1beta1/blocks/latest'
    _SERVICE.methods_by_name['GetBlockByHeight']._options = None
    _SERVICE.methods_by_name['GetBlockByHeight']._serialized_options = b'\x82\xd3\xe4\x93\x021\x12//cosmos/base/tendermint/v1beta1/blocks/{height}'
    _SERVICE.methods_by_name['GetLatestValidatorSet']._options = None
    _SERVICE.methods_by_name['GetLatestValidatorSet']._serialized_options = b'\x82\xd3\xe4\x93\x026\x124/cosmos/base/tendermint/v1beta1/validatorsets/latest'
    _SERVICE.methods_by_name['GetValidatorSetByHeight']._options = None
    _SERVICE.methods_by_name['GetValidatorSetByHeight']._serialized_options = b'\x82\xd3\xe4\x93\x028\x126/cosmos/base/tendermint/v1beta1/validatorsets/{height}'
    _GETVALIDATORSETBYHEIGHTREQUEST._serialized_start = 289
    _GETVALIDATORSETBYHEIGHTREQUEST._serialized_end = 397
    _GETVALIDATORSETBYHEIGHTRESPONSE._serialized_start = 400
    _GETVALIDATORSETBYHEIGHTRESPONSE._serialized_end = 579
    _GETLATESTVALIDATORSETREQUEST._serialized_start = 581
    _GETLATESTVALIDATORSETREQUEST._serialized_end = 671
    _GETLATESTVALIDATORSETRESPONSE._serialized_start = 674
    _GETLATESTVALIDATORSETRESPONSE._serialized_end = 851
    _VALIDATOR._serialized_start = 853
    _VALIDATOR._serialized_end = 969
    _GETBLOCKBYHEIGHTREQUEST._serialized_start = 971
    _GETBLOCKBYHEIGHTREQUEST._serialized_end = 1012
    _GETBLOCKBYHEIGHTRESPONSE._serialized_start = 1014
    _GETBLOCKBYHEIGHTRESPONSE._serialized_end = 1125
    _GETLATESTBLOCKREQUEST._serialized_start = 1127
    _GETLATESTBLOCKREQUEST._serialized_end = 1150
    _GETLATESTBLOCKRESPONSE._serialized_start = 1152
    _GETLATESTBLOCKRESPONSE._serialized_end = 1261
    _GETSYNCINGREQUEST._serialized_start = 1263
    _GETSYNCINGREQUEST._serialized_end = 1282
    _GETSYNCINGRESPONSE._serialized_start = 1284
    _GETSYNCINGRESPONSE._serialized_end = 1321
    _GETNODEINFOREQUEST._serialized_start = 1323
    _GETNODEINFOREQUEST._serialized_end = 1343
    _GETNODEINFORESPONSE._serialized_start = 1346
    _GETNODEINFORESPONSE._serialized_end = 1501
    _VERSIONINFO._serialized_start = 1504
    _VERSIONINFO._serialized_end = 1714
    _MODULE._serialized_start = 1716
    _MODULE._serialized_end = 1768
    _SERVICE._serialized_start = 1771
    _SERVICE._serialized_end = 2931




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/libs/bits/types.proto\x12\x14tendermint.libs.bits"\'\n\x08BitArray\x12\x0c\n\x04bits\x18\x01 \x01(\x03\x12\r\n\x05elems\x18\x02 \x03(\x04B=Z;github.com/tendermint/tendermint/proto/tendermint/libs/bitsb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.libs.bits.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z;github.com/tendermint/tendermint/proto/tendermint/libs/bits'
    _BITARRAY._serialized_start = 58
    _BITARRAY._serialized_end = 97




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.api import annotations_pb2 as _annotations_pb2
from tendermint.p2p import types_pb2 as _types_pb2
from tendermint.types import block_pb2 as _block_pb2
from tendermint.types import types_pb2 as _types_pb2_1
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GetBlockByHeightRequest(_message.Message):
    __slots__ = ['height']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int

    def __init__(self, height: _Optional[int]=...) -> None:
        ...

class GetBlockByHeightResponse(_message.Message):
    __slots__ = ['block', 'block_id']
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    block: _block_pb2.Block
    block_id: _types_pb2_1.BlockID

    def __init__(self, block_id: _Optional[_Union[(_types_pb2_1.BlockID, _Mapping)]]=..., block: _Optional[_Union[(_block_pb2.Block, _Mapping)]]=...) -> None:
        ...

class GetLatestBlockRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetLatestBlockResponse(_message.Message):
    __slots__ = ['block', 'block_id']
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    block: _block_pb2.Block
    block_id: _types_pb2_1.BlockID

    def __init__(self, block_id: _Optional[_Union[(_types_pb2_1.BlockID, _Mapping)]]=..., block: _Optional[_Union[(_block_pb2.Block, _Mapping)]]=...) -> None:
        ...

class GetLatestValidatorSetRequest(_message.Message):
    __slots__ = ['pagination']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest

    def __init__(self, pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class GetLatestValidatorSetResponse(_message.Message):
    __slots__ = ['block_height', 'pagination', 'validators']
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    pagination: _pagination_pb2.PageResponse
    validators: _containers.RepeatedCompositeFieldContainer[Validator]

    def __init__(self, block_height: _Optional[int]=..., validators: _Optional[_Iterable[_Union[(Validator, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class GetNodeInfoRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetNodeInfoResponse(_message.Message):
    __slots__ = ['application_version', 'default_node_info']
    APPLICATION_VERSION_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_NODE_INFO_FIELD_NUMBER: _ClassVar[int]
    application_version: VersionInfo
    default_node_info: _types_pb2.DefaultNodeInfo

    def __init__(self, default_node_info: _Optional[_Union[(_types_pb2.DefaultNodeInfo, _Mapping)]]=..., application_version: _Optional[_Union[(VersionInfo, _Mapping)]]=...) -> None:
        ...

class GetSyncingRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetSyncingResponse(_message.Message):
    __slots__ = ['syncing']
    SYNCING_FIELD_NUMBER: _ClassVar[int]
    syncing: bool

    def __init__(self, syncing: bool=...) -> None:
        ...

class GetValidatorSetByHeightRequest(_message.Message):
    __slots__ = ['height', 'pagination']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    height: int
    pagination: _pagination_pb2.PageRequest

    def __init__(self, height: _Optional[int]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class GetValidatorSetByHeightResponse(_message.Message):
    __slots__ = ['block_height', 'pagination', 'validators']
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    pagination: _pagination_pb2.PageResponse
    validators: _containers.RepeatedCompositeFieldContainer[Validator]

    def __init__(self, block_height: _Optional[int]=..., validators: _Optional[_Iterable[_Union[(Validator, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class Module(_message.Message):
    __slots__ = ['path', 'sum', 'version']
    PATH_FIELD_NUMBER: _ClassVar[int]
    SUM_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    path: str
    sum: str
    version: str

    def __init__(self, path: _Optional[str]=..., version: _Optional[str]=..., sum: _Optional[str]=...) -> None:
        ...

class Validator(_message.Message):
    __slots__ = ['address', 'proposer_priority', 'pub_key', 'voting_power']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    address: str
    proposer_priority: int
    pub_key: _any_pb2.Any
    voting_power: int

    def __init__(self, address: _Optional[str]=..., pub_key: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., voting_power: _Optional[int]=..., proposer_priority: _Optional[int]=...) -> None:
        ...

class VersionInfo(_message.Message):
    __slots__ = ['app_name', 'build_deps', 'build_tags', 'cosmos_sdk_version', 'git_commit', 'go_version', 'name', 'version']
    APP_NAME_FIELD_NUMBER: _ClassVar[int]
    BUILD_DEPS_FIELD_NUMBER: _ClassVar[int]
    BUILD_TAGS_FIELD_NUMBER: _ClassVar[int]
    COSMOS_SDK_VERSION_FIELD_NUMBER: _ClassVar[int]
    GIT_COMMIT_FIELD_NUMBER: _ClassVar[int]
    GO_VERSION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    app_name: str
    build_deps: _containers.RepeatedCompositeFieldContainer[Module]
    build_tags: str
    cosmos_sdk_version: str
    git_commit: str
    go_version: str
    name: str
    version: str

    def __init__(self, name: _Optional[str]=..., app_name: _Optional[str]=..., version: _Optional[str]=..., git_commit: _Optional[str]=..., build_tags: _Optional[str]=..., go_version: _Optional[str]=..., build_deps: _Optional[_Iterable[_Union[(Module, _Mapping)]]]=..., cosmos_sdk_version: _Optional[str]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgTransfer(_message.Message):
    __slots__ = ['receiver', 'sender', 'source_channel', 'source_port', 'timeout_height', 'timeout_timestamp', 'token']
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PORT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    receiver: str
    sender: str
    source_channel: str
    source_port: str
    timeout_height: _client_pb2.Height
    timeout_timestamp: int
    token: _coin_pb2.Coin

    def __init__(self, source_port: _Optional[str]=..., source_channel: _Optional[str]=..., token: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=..., sender: _Optional[str]=..., receiver: _Optional[str]=..., timeout_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=..., timeout_timestamp: _Optional[int]=...) -> None:
        ...

class MsgTransferResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsentinel/plan/v2/plan.proto\x12\x10sentinel.plan.v2\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto"\xb6\x02\n\x04Plan\x12\x12\n\x02id\x18\x01 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x02 \x01(\t\x125\n\x08duration\x18\x03 \x01(\x0b2\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x11\n\tgigabytes\x18\x04 \x01(\x03\x12[\n\x06prices\x18\x05 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12)\n\x06status\x18\x06 \x01(\x0e2\x19.sentinel.types.v1.Status\x127\n\tstatus_at\x18\x07 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01B7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.plan_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _PLAN.fields_by_name['id']._options = None
    _PLAN.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _PLAN.fields_by_name['duration']._options = None
    _PLAN.fields_by_name['duration']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01'
    _PLAN.fields_by_name['prices']._options = None
    _PLAN.fields_by_name['prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PLAN.fields_by_name['status_at']._options = None
    _PLAN.fields_by_name['status_at']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _PLAN._serialized_start = 201
    _PLAN._serialized_end = 511




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Metadata(_message.Message):
    __slots__ = ['chunk_hashes']
    CHUNK_HASHES_FIELD_NUMBER: _ClassVar[int]
    chunk_hashes: _containers.RepeatedScalarFieldContainer[bytes]

    def __init__(self, chunk_hashes: _Optional[_Iterable[bytes]]=...) -> None:
        ...

class Snapshot(_message.Message):
    __slots__ = ['chunks', 'format', 'hash', 'height', 'metadata']
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    chunks: int
    format: int
    hash: bytes
    height: int
    metadata: Metadata

    def __init__(self, height: _Optional[int]=..., format: _Optional[int]=..., chunks: _Optional[int]=..., hash: _Optional[bytes]=..., metadata: _Optional[_Union[(Metadata, _Mapping)]]=...) -> None:
        ...

class SnapshotExtensionMeta(_message.Message):
    __slots__ = ['format', 'name']
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    format: int
    name: str

    def __init__(self, name: _Optional[str]=..., format: _Optional[int]=...) -> None:
        ...

class SnapshotExtensionPayload(_message.Message):
    __slots__ = ['payload']
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    payload: bytes

    def __init__(self, payload: _Optional[bytes]=...) -> None:
        ...

class SnapshotIAVLItem(_message.Message):
    __slots__ = ['height', 'key', 'value', 'version']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    height: int
    key: bytes
    value: bytes
    version: int

    def __init__(self, key: _Optional[bytes]=..., value: _Optional[bytes]=..., version: _Optional[int]=..., height: _Optional[int]=...) -> None:
        ...

class SnapshotItem(_message.Message):
    __slots__ = ['extension', 'extension_payload', 'iavl', 'store']
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    IAVL_FIELD_NUMBER: _ClassVar[int]
    STORE_FIELD_NUMBER: _ClassVar[int]
    extension: SnapshotExtensionMeta
    extension_payload: SnapshotExtensionPayload
    iavl: SnapshotIAVLItem
    store: SnapshotStoreItem

    def __init__(self, store: _Optional[_Union[(SnapshotStoreItem, _Mapping)]]=..., iavl: _Optional[_Union[(SnapshotIAVLItem, _Mapping)]]=..., extension: _Optional[_Union[(SnapshotExtensionMeta, _Mapping)]]=..., extension_payload: _Optional[_Union[(SnapshotExtensionPayload, _Mapping)]]=...) -> None:
        ...

class SnapshotStoreItem(_message.Message):
    __slots__ = ['name']
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str

    def __init__(self, name: _Optional[str]=...) -> None:
        ...
